@@ -4,7 +4,7 @@ use strict;
 use warnings;
 
 
-our $VERSION = '0.004';
+our $VERSION = '0.005';
 
 sub new {
   my $class = shift;
@@ -15,10 +15,10 @@ sub new {
 sub ngram {
   my ($self, $word, $width) = @_;
 
-  $word ||= '';
+  return [] unless (length($word));
 
   return $self->from_tokens(
-    [$self->_tokenize($word)],
+    $self->_tokenize($word),
     $width
   );
 }
@@ -26,22 +26,21 @@ sub ngram {
 sub from_tokens {
   my ($self, $tokens, $width) = @_;
 
-  $width = 1 unless defined $width;
+  $width = 1 unless ($width && $width =~ m/^[1-9][0-9]*$/x);
+
+  return [join('',@$tokens)] unless ($width <= scalar @$tokens);
 
   my @ngrams;
-  return @ngrams 
-    unless ($width =~ m/^[1-9][0-9]*$/x && $width <= scalar(@$tokens));
 
   for my $i (0..scalar(@$tokens)-$width) {
     my $ngram = join('',@$tokens[$i..$i+$width-1]);
     push @ngrams,$ngram;
   }
 
-  return @ngrams;
-
+  return \@ngrams;
 }
 
-sub _tokenize { ($_[1] =~ m/(\X)/g) }
+sub _tokenize { [$_[1] =~ m/(\X)/g] }
 
 1;
 
@@ -79,15 +78,18 @@ Building n-grams is one of them.
 
 =head2 ngram
 
-  my @ngram = $object->ngram($string, $width);
+  my $array_ref = $object->ngram($string, $width);
   
-C<$string> ... string of characters
+C<$string> ...... string of characters
   
-C<$width> ... length of the resulting tokens. Default is 1.
+C<$width> ....... length of the resulting tokens. Default is 1.
+
+C<$array_ref> ... reference to array of ngram tokens
+
+Returns one token with the unmodified C<$string> if the number of graphemes in C<$string> is lower than C<$width>.
+Returns an empty C<$array_ref> if C<$string> is empty or undef. NOTE: maybe this will be changed in future.
+Defaults to length = 1 if C<$width> is not an integer larger than 0. 
 
-Returns an empty list if the number of graphemes in C<$string> is lower than C<$width>,
-or if C<$width> is not an integer larger than 0.    
-  
 =head2 from_tokens
 
   my @ngram = $object->from_tokens(\@tokens, $width);
